﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace EvidenceStudentu
{
    public partial class Form1 : Form
    {
        private List<Student> students = new List<Student>();
        private string currentFilename = null;
        public Form1()
        {
            InitializeComponent();
        }

        private void novaToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if (currentFilename == "")
            {
                if(saveFileDialog1.ShowDialog()==DialogResult.OK)
                {
                    currentFilename = saveFileDialog1.FileName;
                }
                
            }
            saveStudents();
            students.Clear();
            updateGIU();
        }

        private void updateGIU()
        {
            listBox1.Items.Clear();
            foreach(Student student in students)
            {
                listBox1.Items.Add(student);
            }
            numStudents.Text = listBox1.Items.Count.ToString();
        }

        private void saveStudents()
        {
            if (currentFilename != "")
            {
                using (StreamWriter writer = new StreamWriter(currentFilename))
                {
                    foreach (Student student in students)
                    {
                        writer.WriteLine(student);
                    }
                }
            }
        }

        private void nactiToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if(openFileDialog1.ShowDialog()==DialogResult.OK)
            {
                loadStudents(openFileDialog1.FileName);
                updateGIU();
            }
        }

        private void loadStudents(string fileName)
        {
            using (StreamReader reader = new StreamReader(fileName))
            {
                string line;
                while((line=reader.ReadLine())!= null)
                {
                    Student student = csvToStudent(line);
                    students.Add(student);
                }
            }
        }

        private Student csvToStudent(string line)
        {
            Student student = new Student();
            string[] parts = line.Split(',');
            if (parts.Length != 4)
            {
                throw new EvaluateException("Invalid file format: " +line);
            }
            long id;
            Int64.TryParse(parts[0], out id);
            student.id = id;
            student.name = parts[1];
            student.field = parts[2];
            int year;
            Int32.TryParse(parts[3], out year);
            student.year = year;
            return student;
        }

        private void ulozToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if(currentFilename == null)
            {
                if(saveFileDialog1.ShowDialog()==DialogResult.OK)
                {
                    currentFilename = saveFileDialog1.FileName;
                    
                }
            }
            saveStudents();
        }

        private void toolStripMenuItem3_Click(object sender, EventArgs e)
        {
            if(saveFileDialog1.ShowDialog()==DialogResult.OK)
            {
                currentFilename = saveFileDialog1.FileName;
                saveStudents();
            }
        }

        private void pridatToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AddStudentDialog dialog = new AddStudentDialog();
            if(dialog.ShowDialog()==DialogResult.OK)
            {
                students.Add(dialog.student);
                updateGIU();
            }
        }

        private void odebratToolStripMenuItem_Click(object sender, EventArgs e)
        {
            if(listBox1.SelectedIndex>=0)
            {
                students.RemoveAt(listBox1.SelectedIndex);
                updateGIU();
            }
        }

        private void konecToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }
    }
}
